Documentation
¶
Overview ¶
Package pubsub is used for twitch's pubsub. This implementation is not tested at all.
Index ¶
Constants ¶
const AppName string = "goPurple/pubsub"
AppName is the name of the application
const FullVersion string = AppName + VersionMajor + "." + VersionMinor + VersionBuild
FullVersion contains the full name and version of this package in a printable string
const VersionBuild string = "d"
VersionBuild is the type of this release. s(table), b(eta), d(evelopment), n(ightly)
const VersionMajor string = "0"
VersionMajor 0 means in development, >1 ensures compatibility with each minor version, but breakes with new major version
const VersionMinor string = "1"
VersionMinor introduces changes that require a new version number. If the major version is 0, they are likely to break compatibility
Variables ¶
var ArchiumDataIdentifier = "Message"
ArchiumDataIdentifier which contains the actual payload
var ArchiumPrefix = "twitch.pubsub."
ArchiumPrefix for twitch pubsub messages
Functions ¶
This section is empty.
Types ¶
type PsResult ¶
type PsResult struct {
Type string `json:"type"`
Nonce string `json:"nonce"`
Error string `json:"error"`
Data struct {
Topic string `json:"topic"`
RawMessage string `json:"message"`
Message map[string]interface{} `json:"-"`
} `json:"data"`
}
PsResult is the message sent by pubsub